"use client";

import { useState } from "react";
import {
  Chart as ChartJS,
  ArcElement,
  Tooltip,
  Legend,
  ChartData,
  ChartOptions,
} from "chart.js";
import { Doughnut } from "react-chartjs-2";
import TransactionForm from "./TransactionForm";
import { Transaction } from "@/lib/db";
import { PlusIcon, MinusIcon } from "@heroicons/react/24/outline";

ChartJS.register(ArcElement, Tooltip, Legend);

interface HomeTabProps {
  balance: number;
  transactions: Transaction[];
  onAddTransaction: () => void;
}

export default function HomeTab({
  balance,
  transactions,
  onAddTransaction,
}: HomeTabProps) {
  const [isFormOpen, setIsFormOpen] = useState(false);
  const [formType, setFormType] = useState<"INCOME" | "EXPENSE">("INCOME");

  // Calcular totales
  const totalIncome = transactions
    .filter((t) => t.type === "INCOME")
    .reduce((acc, t) => acc + t.amount, 0);

  const totalExpenses = transactions
    .filter((t) => t.type === "EXPENSE")
    .reduce((acc, t) => acc + t.amount, 0);

  const chartData: ChartData<"doughnut"> = {
    labels: ["Disponible", "Gastos", "Ingresos"],
    datasets: [
      {
        data: [balance, totalExpenses, totalIncome],
        backgroundColor: [
          "rgba(34, 197, 94, 0.8)", // Verde para disponible
          "rgba(239, 68, 68, 0.8)", // Rojo para gastos
          "rgba(59, 130, 246, 0.8)", // Azul para ingresos
        ],
        borderColor: [
          "rgba(34, 197, 94, 1)",
          "rgba(239, 68, 68, 1)",
          "rgba(59, 130, 246, 1)",
        ],
        borderWidth: 1,
      },
    ],
  };

  const chartOptions: ChartOptions<"doughnut"> = {
    responsive: true,
    maintainAspectRatio: false,
    plugins: {
      legend: {
        display: false,
      },
      tooltip: {
        callbacks: {
          label: function (context) {
            const label = context.label || "";
            const value = (context.raw as number) || 0;
            return `${label}: $${value.toFixed(2)}`;
          },
        },
      },
    },
    cutout: "70%",
  };

  return (
    <div className="space-y-6">
      {/* Gráfica y Resumen */}
      <div className="bg-gray-800 rounded-2xl p-6">
        <div className="flex flex-col md:flex-row items-center justify-between mb-6">
          <div className="text-center md:text-left mb-4 md:mb-0">
            <h2 className="text-lg text-gray-400">Balance actual</h2>
            <p className="text-4xl font-bold text-green-500">
              ${balance.toFixed(2)}
            </p>
          </div>
          <div className="grid grid-cols-2 gap-4 w-full md:w-auto">
            <div className="bg-gray-700 rounded-xl p-3">
              <p className="text-sm text-gray-400">Ingresos</p>
              <p className="text-lg font-semibold text-green-500">
                ${totalIncome.toFixed(2)}
              </p>
            </div>
            <div className="bg-gray-700 rounded-xl p-3">
              <p className="text-sm text-gray-400">Gastos</p>
              <p className="text-lg font-semibold text-red-500">
                ${totalExpenses.toFixed(2)}
              </p>
            </div>
          </div>
        </div>

        <div className="relative h-64 mb-6">
          <Doughnut data={chartData} options={chartOptions} />
          <div className="absolute inset-0 flex items-center justify-center">
            <div className="text-center">
              <p className="text-sm text-gray-400">Total</p>
              <p className="text-2xl font-bold text-white">
                ${balance.toFixed(2)}
              </p>
            </div>
          </div>
        </div>

        {/* Leyenda */}
        <div className="grid grid-cols-3 gap-4">
          <div className="flex items-center space-x-2">
            <div className="w-3 h-3 rounded-full bg-green-500"></div>
            <span className="text-sm text-gray-400">Disponible</span>
          </div>
          <div className="flex items-center space-x-2">
            <div className="w-3 h-3 rounded-full bg-red-500"></div>
            <span className="text-sm text-gray-400">Gastos</span>
          </div>
          <div className="flex items-center space-x-2">
            <div className="w-3 h-3 rounded-full bg-blue-500"></div>
            <span className="text-sm text-gray-400">Ingresos</span>
          </div>
        </div>
      </div>

      {/* Botones de Acción */}
      <div className="flex justify-center space-x-4">
        <button
          onClick={() => {
            setFormType("INCOME");
            setIsFormOpen(true);
          }}
          className="bg-green-600 text-white px-6 py-3 rounded-xl flex items-center shadow-lg hover:bg-green-700 transition-colors"
        >
          <PlusIcon className="h-6 w-6 mr-2" />
          Ingreso
        </button>
        <button
          onClick={() => {
            setFormType("EXPENSE");
            setIsFormOpen(true);
          }}
          className="bg-red-600 text-white px-6 py-3 rounded-xl flex items-center shadow-lg hover:bg-red-700 transition-colors"
        >
          <MinusIcon className="h-6 w-6 mr-2" />
          Gasto
        </button>
      </div>

      {/* Lista de Transacciones */}
      <div className="bg-gray-800 rounded-2xl p-6">
        <h2 className="text-xl font-semibold mb-4 text-white">
          Últimas transacciones
        </h2>
        <div className="space-y-4">
          {transactions.length > 0 ? (
            transactions.map((transaction) => (
              <div
                key={transaction.id}
                className="flex items-center justify-between p-4 bg-gray-700 rounded-xl"
              >
                <div>
                  <p className="font-medium text-white">
                    {transaction.category}
                  </p>
                  <p className="text-sm text-gray-400">{transaction.title}</p>
                </div>
                <p
                  className={`font-semibold ${
                    transaction.type === "INCOME"
                      ? "text-green-500"
                      : "text-red-500"
                  }`}
                >
                  {transaction.type === "INCOME" ? "+" : "-"}$
                  {transaction.amount.toFixed(2)}
                </p>
              </div>
            ))
          ) : (
            <p className="text-gray-400 text-center">
              No hay transacciones aún
            </p>
          )}
        </div>
      </div>

      {/* Formulario de Transacción */}
      <TransactionForm
        isOpen={isFormOpen}
        onClose={() => setIsFormOpen(false)}
        type={formType}
        onTransactionAdded={onAddTransaction}
      />
    </div>
  );
}
